/**
 * List repository for an organization.
 * @function listOrgRepo
 * @param {string} name - Name of organization.
 * @param {function} callback - Callback when done.
 */

"use strict";

const _apiRequest = require('./_api_request'),
    async = require('async'),
    argx = require('argx');

const MAX_COUNT = 100;

/** @lends listOrgRepo */
function listOrgRepo(name, options, callback) {
    let args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    async.concatSeries([1, 2, 3], (page, callback) => {
        let pathname = `/orgs/${name}/repos?per_page=${MAX_COUNT}&page=${page}`;
        _apiRequest(pathname, (err, res, body) => {
            if (err) {
                callback(err);
            } else {
                let success = res.statusCode == 200;
                if (success) {
                    let data = JSON.parse(body).map(listOrgRepo.parse);
                    setTimeout(()=> {
                        callback(null, data);
                    }, 100);
                } else {
                    callback(new Error('Request failed with status: ' + res.statusCode));
                }
            }
        });
    }, callback);
}
listOrgRepo.parse = function parse(data) {
    return {
        name: data.name,
        full_name: data.full_name,
        private: data.private,
        description: data.description,
        url: data.url,
        fork: data.fork
    };
};

module.exports = listOrgRepo;
